@@ -1,4 +1,4 @@
-source("./R/dcem_train.R")
+#source("./R/dcem_train.R")
 #' dcem_test: Part of DCEM package.
 #'
 #' For demonstrating the execution on the bundled dataset.
@@ -58,14 +58,10 @@ source("./R/dcem_train.R")
 #' dcem_test()
 #'
 #' @references
-#' Using data to build a better EM: EM* for big data.
+#' Parichit Sharma, Hasan Kurban, Mehmet Dalkilic DCEM: An R package for clustering big data via
+#' data-centric modification of Expectation Maximization, SoftwareX, 17, 100944 URL
+#' https://doi.org/10.1016/j.softx.2021.100944
 #'
-#' Hasan Kurban, Mark Jenne, Mehmet M. Dalkilic
-#'(2016) <https://doi.org/10.1007/s41060-017-0062-1>.
-#'
-#' @author Parichit Sharma \email{parishar@iu.edu}, Hasan Kurban, Mark Jenne, Mehmet Dalkilic
-#'
-#' This work is partially supported by NCI Grant 1R01CA213466-01.
 #' @export
 
 dcem_test <- function()
